@@ -7,50 +7,38 @@ import os
 import spiderosm.centerline
 import spiderosm.config
 import spiderosm.geo
+import spiderosm.log
 import spiderosm.match
 
 def _match_city():
     global spiderosm
+
     project = 'portland'
-
-    # allow out_dir and gis_data_dir and bbox to be set in config files (.spiderosm.json)
-    # DATA DIRS
-    conf = spiderosm.config.settings
-    conf['gis_data_dir'] = 'data'
-    conf['out_dir'] = os.path.join('data',project)
-
-    #BOUNDING BOX
-    #if bbox set to None, city data bounding box plus a buffer is used.
+    gis_data_dir = spiderosm.config.settings.get('gis_data_dir', 'data')
+    out_dir = spiderosm.config.settings.get('out_dir', os.path.join('data',project))
+    spiderosm.log.info('gis_data_dir=%s out_dir=%s', gis_data_dir, out_dir)
+    # if bbox set to None, city data bounding box plus a buffer is used.
     # approximately portland city boundary, with 1 mile buffer.
     portland_bbox = (7604005.67,651319.12,7696978.42,732248.02)
-    conf['bbox'] = spiderosm.geo.buffer_box(portland_bbox,5280) # buffer by 1 mi
-
-    spiderosm.config.read_config_files()
-    print 'spiderosm.config.settings:', spiderosm.config.settings
-
-    gis_data_dir = conf['gis_data_dir']
-    out_dir = conf['out_dir']
-    bbox = conf['bbox']
-    print 'gis_data_dir=%s out_dir=%s' % (gis_data_dir,out_dir)
-    print 'bbox:', bbox 
+    bbox = spiderosm.geo.buffer_box(portland_bbox,5280) # buffer by 1 mi
+    spiderosm.log.info('gis_data_dir=%s out_dir=%s\n  bbox: %s' % (gis_data_dir, out_dir, str(bbox)))
 
     # make sure out_dir exists
     if not os.path.exists(out_dir): os.makedirs(out_dir)
-    
+
     # if a database is enabled write output to it too
-    # NOTE: currently writes to only one database even if multiple databases are enabled.
-    write_to_postgis = True
-    write_to_spatialite = True
-    db = None
-    if write_to_postgis and (not db) and conf.get('postgis_enabled'):
+    if  spiderosm.config.settings.get('postgis_enabled'):
         import spiderosm.postgis
-        db = spiderosm.postgis.PGIS(project)
-        print 'Results will be written to postgis database %s' % project
-    if write_to_spatialite and (not db) and conf.get('spatialite_enabled'):
+        db_name = spiderosm.config.settings.get('postgis_dbname', project)
+        db = spiderosm.postgis.PGIS(db_name)
+        spiderosm.log.info('Results will be written to postgis database %s', db_name)
+    elif spiderosm.config.settings.get('spatialite_enabled'):
         import spiderosm.spatialite
         sqlite_fn = os.path.join(out_dir, project + '.sqlite')
         db = spiderosm.spatialite.Slite(sqlite_fn)
-        print 'Results will be written to spatialite database %s' % sqlite_fn
+        spiderosm.log.info('Results will be written to spatialite database %s', sqlite_fn)
+    else:
+        db = None
 
     m = spiderosm.match.Match(
             project=project,
